/***********************************************************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only 
* intended for use with Renesas products. No other uses are authorized. This 
* software is owned by Renesas Electronics Corporation and is protected under 
* all applicable laws, including copyright laws.
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING 
* THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT 
* LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE 
* AND NON-INFRINGEMENT.  ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
* TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS 
* ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES SHALL BE LIABLE 
* FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR 
* ANY REASON RELATED TO THIS SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE 
* BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software 
* and to discontinue the availability of this software.  By using this software, 
* you agree to the additional terms and conditions found by accessing the 
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2011, 2013 Renesas Electronics Corporation. All rights reserved.
***********************************************************************************************************************/

/***********************************************************************************************************************
* File Name    : r_adc_user.c
* Device(s)    : R5F110PJAFB
* Tool-Chain   : CA78K0R
* Description  : This file implements device driver for ADC module.
* Creation Date: 2014-06-23
***********************************************************************************************************************/

/***********************************************************************************************************************
Pragma directive
***********************************************************************************************************************/
#pragma interrupt INTAD r_adc_interrupt


/***********************************************************************************************************************
Includes
***********************************************************************************************************************/
#include "r_macrodriver.h"
#include "r_user.h"


/***********************************************************************************************************************
Global variables and functions
***********************************************************************************************************************/
unsigned char AD_ResultCount;
unsigned int AD_CurrentValue;
boolean BatteryWarningFlg;

void R_ADC_Setting(void);
void R_ADC_Start(void);
void R_ADC_Stop(void);
void R_ADC_Set_OperationOn(void);
void R_ADC_Set_OperationOff(void);



/***********************************************************************************************************************
* Function Name: R_ADC_VolSetting
* Description  : This function initializes the AD converter.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_ADC_Setting(void)
{
    ADCEN = 1U;  			/* supply AD clock */
    ADM0 = 0x00U;			/* disable AD conversion and clear ADM0 register */

    ADMK = 1U;  			/* disable INTAD interrupt */
    ADIF = 0U;  			/* clear INTAD interrupt flag */

    /* Set INTAD high priority */
    ADPR1 = 0U;
    ADPR0 = 0U;

    /* Set ANI0 - ANI7 pin as analog input */
    PM15 = 0x81U;
    ADPC = 0x02U;			//ANI0/P150 is used to A/D converter

	ADM0 = 0b00111000;		//conversion clock: fclk, conversion time: 5.4us
//	ADM1 = 0b00100000;		//software trigger mode, one-shot conversion mode
	ADM1 = 0b00000000;		//software trigger mode, sequential conversion mode
	ADM2 = 0b00000000;		//supplied from vdd, vss, 12 bit resolution
	ADUL = 0x0FFU;
	ADLL = 0x00U;
	ADS = 0b00000000;		//Analog input channel: ANI0
	ADTES = 0x00U;
}



/***********************************************************************************************************************
* Function Name: R_ADC_Start
* Description  : This function starts the AD converter.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_ADC_Start(void)
{
    ADIF = 0U;  	/* clear INTAD interrupt flag */
    ADMK = 0U;  	/* enable INTAD interrupt */
    ADCS = 1U;  	/* enable AD conversion */
}

/***********************************************************************************************************************
* Function Name: R_ADC_Stop
* Description  : This function stops the AD converter.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_ADC_Stop(void)
{
    ADCS = 0U;  	/* disable AD conversion */
    ADMK = 1U;  	/* disable INTAD interrupt */
    ADIF = 0U;  	/* clear INTAD interrupt flag */
}

/***********************************************************************************************************************
* Function Name: R_ADC_Set_OperationOn
* Description  : This function enables comparator operation.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_ADC_Set_OperationOn(void)
{
    ADCE = 1U;  	/* enable AD comparator */
}

/***********************************************************************************************************************
* Function Name: R_ADC_Set_OperationOff
* Description  : This function stops comparator operation.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_ADC_Set_OperationOff(void)
{
    ADCE = 0U;  	/* disable AD comparator */
}




/***********************************************************************************************************************
* Function Name: r_adc_interrupt
* Description  : This function is INTAD interrupt service routine.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
__interrupt static void r_adc_interrupt(void)
{
    	unsigned int	da_dat_int;
    	da_dat_int = ADCR;

	if(AD_ResultCount==0)
	{
		AD_ResultCount++;
		return;
	}
	else
	{
		AD_ResultCount++;
		AD_CurrentValue += da_dat_int;
		if(AD_ResultCount>=9)
		{
			R_ADC_Stop();
			R_ADC_Set_OperationOff();
			AD_ResultCount = 0;
			ADCEN = 0U;
			AD_CurrentValue = AD_CurrentValue >> 3;			//Calculating the average

			if(AD_CurrentValue <= 0x0300)
			{
				BatteryWarningFlg = 1;
				Disp_Buff[2] |= 0x01;
			}
			else
			{
				BatteryWarningFlg = 0;
				Disp_Buff[2] |= 0x00;
			}
		}
	}
}






