/***********************************************************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only 
* intended for use with Renesas products. No other uses are authorized. This 
* software is owned by Renesas Electronics Corporation and is protected under 
* all applicable laws, including copyright laws.
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING 
* THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT 
* LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE 
* AND NON-INFRINGEMENT.  ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
* TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS 
* ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES SHALL BE LIABLE 
* FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR 
* ANY REASON RELATED TO THIS SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE 
* BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software 
* and to discontinue the availability of this software.  By using this software, 
* you agree to the additional terms and conditions found by accessing the 
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2011, 2013 Renesas Electronics Corporation. All rights reserved.
***********************************************************************************************************************/

/***********************************************************************************************************************
* File Name    : r_it_user.c
* Device(s)    : R5F1100PJAFB
* Tool-Chain   : CA78K0R
* Description  : This file implements device driver for interval timer module.
* Creation Date: 2014-06-23
***********************************************************************************************************************/

/***********************************************************************************************************************
Pragma directive
***********************************************************************************************************************/
#pragma interrupt INTIT r_it_interrupt


/***********************************************************************************************************************
Includes
***********************************************************************************************************************/
#include "r_macrodriver.h"


/***********************************************************************************************************************
Global variables and functions
***********************************************************************************************************************/

void R_IT_Stop(void);
void R_IT_Start(void);


/***********************************************************************************************************************
* Function Name: R_IT_Setting
* Description  : This function initializes the interval timer.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_IT_Stop(void)
{
	TMKAEN = 0U;		/*supply IT module*/
//	OSMC = 0x00;		/*Subsystem clock is enable*/

	TMKAMK = 1U;		/*Disable INTIT interrupt*/
	TMKAIF = 0U;		/*Clear INTIT interrupt request flag*/

	/* Set INTIT high priority */
	TMKAPR0 = 0U;
	TMKAPR1 = 0U;

	ITMC = 0x0028;		/* Interval timer stop, 1.25ms interrupt */
}




/***********************************************************************************************************************
* Function Name: R_IT_Start
* Description  : This function start the interval timer.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_IT_Start(void)
{
	TMKAEN = 1U;		/*supply IT module*/
//	OSMC = 0x00;		/*Subsystem clock is enable*/

	TMKAMK = 0U;		/*Disable INTIT interrupt*/
	TMKAIF = 0U;		/*Clear INTIT interrupt request flag*/

	/* Set INTIT high priority */
	TMKAPR0 = 0U;
	TMKAPR1 = 0U;

	ITMC = 0x8028;		/* Interval timer stop, 1.25ms interrupt */
}



/***********************************************************************************************************************
* Function Name: r_it_interrupt
* Description  : This function is INTIT interrupt service routine, 1.25ms interrupt.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
__interrupt static void r_it_interrupt(void)
{
 
}



