/***********************************************************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only 
* intended for use with Renesas products. No other uses are authorized. This 
* software is owned by Renesas Electronics Corporation and is protected under 
* all applicable laws, including copyright laws.
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING 
* THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT 
* LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE 
* AND NON-INFRINGEMENT.  ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
* TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS 
* ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES SHALL BE LIABLE 
* FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR 
* ANY REASON RELATED TO THIS SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE 
* BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software 
* and to discontinue the availability of this software.  By using this software, 
* you agree to the additional terms and conditions found by accessing the 
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2011, 2013 Renesas Electronics Corporation. All rights reserved.
***********************************************************************************************************************/

/***********************************************************************************************************************
* File Name    : r_it_user.c
* Device(s)    : R5F1100PJAFB
* Tool-Chain   : CA78K0R
* Description  : This file implements device driver for interval timer module.
* Creation Date: 2014-06-23
***********************************************************************************************************************/

/***********************************************************************************************************************
Pragma directive
***********************************************************************************************************************/
#pragma interrupt INTP2 r_poweron_interrupt
#pragma interrupt INTP5 r_mode_interrupt


/***********************************************************************************************************************
Includes
***********************************************************************************************************************/
#include "r_macrodriver.h"

/***********************************************************************************************************************
Global variables and functions
***********************************************************************************************************************/
unsigned char Sys_status;
unsigned char ModeCount;

/*
union bit_def Power_status;
#define Power_on_flg Power_status.bi.b0
#define Power_off_flg Power_status.bi.b1
*/

/*
boolean Power_on_flg;
boolean Power_off_flg;
*/


/***********************************************************************************************************************
* Function Name: r_mode_interrupt
* Description  : This function is key interrupt, it is used to system operation mode setting.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
__interrupt static void r_mode_interrupt(void)
{
	unsigned char i, tem_data1;

	tem_data1 = P0;

	for(i=0; i<250; i++)
	{
		feed_dog();
		NOP();
		if(tem_data1 != P0)
		{
			return;
		}
	}

	tem_data1 &= 0x50U;

	if(tem_data1 == 0x10U)
	{
		if(ModeCount == 0x00)
		{
			if(Sys_status == 0x00)
			{
				Sys_status = 0x20;
				ModeCount++;
				PIF5 = 0U;			/* Disable intp5 MODE KEY */
			}
			else
			{
				PIF5 = 0U;			/* Disable intp5 MODE KEY */
				Sys_status = 0;
				ModeCount = 0;
			}
		}
		else if(ModeCount == 0x01)
		{
			if(Sys_status == 0x21)
			{
				ModeCount++;
				PIF5 = 0U;			/* Disable intp5 MODE KEY */
			}
			else
			{
				PIF5 = 0U;			/* Disable intp5 MODE KEY */
				Sys_status = 0;
				ModeCount = 0;
			}
		}
		else if(ModeCount == 0x02)
		{
			if(Sys_status == 0x22)
			{
				ModeCount++;
				PIF5 = 0U;			/* Disable intp5 MODE KEY */
				PMK5 = 1U;
			}
			else
			{
				PIF5 = 0U;			/* Disable intp5 MODE KEY */
				Sys_status = 0;
				ModeCount = 0;
			}
		}
	}
//	else
//	{
//		PIF5 = 0U;			/* Disable intp5 MODE KEY */
//		Sys_status = 0;
//		ModeCount = 0;
//	}
}


/***********************************************************************************************************************
* Function Name: r_poweron_interrupt
* Description  : This function is key interrupt, it is used to power on judgement
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
__interrupt static void r_poweron_interrupt(void)
{
	unsigned char i, tem_data1;

	tem_data1 = P0;

	for(i=0; i<250; i++)
	{
		feed_dog();
		NOP();
		if(tem_data1 != P0)
		{
			return;
		}
	}

	tem_data1 &= 0x50U;

	if(tem_data1 == 0x40U)
	{
		if(Sys_status == 0)
		{
			Sys_status = 0x10;
			PIF2 = 0;
			PIF5 = 0U;		/* Disable intp5 MODE KEY */
			PMK5 = 1U;
		}
		else
		{
			Sys_status = 0;
			PIF2 = 0;
			PIF5 = 0U;		/* enable intp5 MODE KEY */
			PMK5 = 0U;
		}
	}
//	else
//	{
//		Sys_status = 0;
//		PIF2 = 0;
//		PIF5 = 0U;			/* enable intp5 MODE KEY */
//		PMK5 = 0U;
//	}
}


