/***********************************************************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only 
* intended for use with Renesas products. No other uses are authorized. This 
* software is owned by Renesas Electronics Corporation and is protected under 
* all applicable laws, including copyright laws.
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING 
* THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT 
* LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE 
* AND NON-INFRINGEMENT.  ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
* TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS 
* ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES SHALL BE LIABLE 
* FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR 
* ANY REASON RELATED TO THIS SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE 
* BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software 
* and to discontinue the availability of this software.  By using this software, 
* you agree to the additional terms and conditions found by accessing the 
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2013 Renesas Electronics Corporation. All rights reserved.
***********************************************************************************************************************/

/***********************************************************************************************************************
* File Name    : r_lcd_user.c
* Device(s)    : R5F110PJAFB
* Tool-Chain   : CA78K0R
* Description  : This file implements device driver for LCD module.
* Creation Date: 2014/6/25
***********************************************************************************************************************/

/***********************************************************************************************************************
Pragma directive
***********************************************************************************************************************/
/* Start user code for pragma. Do not edit comment generated here */
/* End user code. Do not edit comment generated here */

/***********************************************************************************************************************
Includes
***********************************************************************************************************************/
#include "r_macrodriver.h"
#include "r_user.h"
#include "stdlib.h"

/* Start user code for include. Do not edit comment generated here */
/* End user code. Do not edit comment generated here */



/***********************************************************************************************************************
Global variables and functions
***********************************************************************************************************************/
const unsigned char digit_tab[10] = {0xEE, 0x24, 0xBA, 0xB6, 0x74, 0xD6, 0xDE, 0xA4, 0xFE, 0xF6};
const unsigned char seg1_tab[8] = {0x01, 0x03, 0x07, 0x0F, 0x1F, 0x3F, 0x7F, 0xFF};
const unsigned char seg2_tab[8] = {0x80, 0xC0, 0xE0, 0xF0, 0xF8, 0xFC, 0xFE, 0xFF};
unsigned char Disp_Buff[25];

void R_LCD_Create(void);
void R_LCD_Start(void);
void R_LCD_Stop(void);
void R_LCD_Voltage_On(void);
void R_LCD_Voltage_Off(void);
void R_LCD_ClearZero(void);
void R_LCD_Allshine(void);
void ErrorDisplay(void);

void ModeDisplay(void);
void NormalDisplay(void);
void DisplayColumn(void);
void SegDisplay(void);

/* Start user code for global. Do not edit comment generated here */
/* End user code. Do not edit comment generated here */

/***********************************************************************************************************************
* Function Name: R_LCD_Create
* Description  : This function initializes the LCD module.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_LCD_Create(void)
{
    LCDM1 = 0x00U;		/* disable LCD clock operation */

//    LCDM0 = 0x16U;		/* External resistant division method */
    				/* 8-time slice, 1/4 bias method */

      LCDM0 = 0x56U;				
      LCDM1 = 0x21U;
      VLCD = 0x07U;
    
				
    ISCLCD &= ~(unsigned char)0x00U;	/* Set VL3 pin */

    LCDC0 = 0x17U;		/* fMAIN/2^16 */
}
/***********************************************************************************************************************
* Function Name: R_LCD_Start
* Description  : This function enables the LCD display.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_LCD_Start(void)
{
    LCDON = 1U;
}
/***********************************************************************************************************************
* Function Name: R_LCD_Stop
* Description  : This function disables the LCD display.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_LCD_Stop(void)
{
    LCDON = 0U;
}
/***********************************************************************************************************************
* Function Name: R_LCD_Voltage_On
* Description  : This function enables voltage boost circuit or capacitor split circuit.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_LCD_Voltage_On(void)
{
    SCOC = 1U;
}




/***********************************************************************************************************************
* Function Name: R_LCD_Voltage_Off
* Description  : This function disables voltage boost circuit or capacitor split circuit.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_LCD_Voltage_Off(void)
{
    SCOC = 0U;
}

/* Start user code for adding. Do not edit comment generated here */
/* End user code. Do not edit comment generated here */


/***********************************************************************************************************************
* Function Name: R_LCD_ClearZero
* Description  : This function clear all LCD display data registers.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_LCD_ClearZero(void)
{
	unsigned char *ip_add;
	unsigned char i;
	
	ip_add = (unsigned char *)0xF0404U;
	for(i=0; i<=20; i++)
	{
		feed_dog();
		*ip_add = 0x00U;
		ip_add++;
	}

	for(i=0; i<=20; i++)
	{
		feed_dog();
		Disp_Buff[i] = 0x00;
	}
}


/***********************************************************************************************************************
* Function Name: R_LCD_Allshine
* Description  : This function clear all LCD display data registers.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_LCD_Allshine(void)
{
	unsigned char *ip_add;
	unsigned char i;
	
	ip_add = (unsigned char *)0xF0404U;
	for(i=0; i<=20; i++)
	{
		feed_dog();
		*ip_add = 0xFFU;
		ip_add++;
	}

	for(i=0; i<=20; i++)
	{
		feed_dog();
		Disp_Buff[i] = 0xFF;
	}
}


/***********************************************************************************************************************
* Function Name: ModeDisplay
* Description  : This function is used to display the mode value.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void ModeDisplay(void)
{
//	unsigned char *ip_add;
	unsigned char i;

	Disp_Buff[0] = 0x00;
	Disp_Buff[1] = 0xEE;
	Disp_Buff[2] = 0x24;

	for(i=3; i<=20; i++)
	{
		feed_dog();
		Disp_Buff[i] = 0x00;
	}

	SegDisplay();
/*
	ip_add = (unsigned char *)0xF0404U;
	*ip_add = 0xEE;
	ip_add++;
	*ip_add = 0xEE;
	ip_add++;
	*ip_add = 0x24;
	ip_add++;

	for(i=0; i<=17; i++)
	{
		feed_dog();
		*ip_add = 0x00;
		ip_add++;
	}
*/
}


/***********************************************************************************************************************
* Function Name: NormalDisplay
* Description  : This function is used to display the normal value.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void NormalDisplay(void)
{
	unsigned int mmHg_Value;
	unsigned char i;
	unsigned char *ip_add, *id_add;

	for(i=0; i<=20; i++)
	{
		feed_dog();
		Disp_Buff[i]=0x00;
	}
	
	mmHg_Value = wtobcd(BloodPressureValue);
	ip_add = (unsigned char *)(&mmHg_Value);
	id_add = &digit_tab[0];

	i = *(ip_add+1);
	i &= 0x0F;
	Disp_Buff[0] = *(id_add + i);

	i = *ip_add;
	i &= 0xF0;
	i = i >> 4;
	Disp_Buff[1] = *(id_add + i);
	Disp_Buff[1] |= 0x01;

	i = *ip_add;
	i &= 0x0F;
	Disp_Buff[2] = *(id_add + i);

	if(mmHg_Value >= 0x0020)
	{
		DisplayColumn();
	}

	if(BatteryWarningFlg)
	{
		Disp_Buff[2] |= 0x01;
	}

	SegDisplay();
}

/***********************************************************************************************************************
* Function Name: DisplayColumn
* Description  : This function is used to display the simulating mercury column.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void DisplayColumn(void)
{
	unsigned char i;
	unsigned long int D_value;
	ldiv_t lx;

	D_value = BloodPressureValue - 19;
	lx = ldiv(D_value, 16);

	if(lx.quot >= 1)
	{
		for(i=1; i<=lx.quot; i++)
		{
			feed_dog();
			Disp_Buff[2+i] = 0xFF;
		}

		if(lx.rem != 0)
		{
			i = lx.quot & 0x01;
			if(i == 0)
			{
				Disp_Buff[3+lx.quot] = seg1_tab[(lx.rem-1)/2];
			}
			else
			{
				Disp_Buff[3+lx.quot] = seg2_tab[(lx.rem-1)/2];
			}
		}
	}
	else
	{
		Disp_Buff[3] = seg1_tab[(lx.rem-1)/2];
	}
}




/***********************************************************************************************************************
* Function Name: SegDisplay
* Description  : This function is used to display all LCD segments.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void SegDisplay(void)
{
	unsigned char *ip_add;
	unsigned char i;

	ip_add = (unsigned char *)0xF0404U;
	for(i=0; i<=20; i++)
	{
		feed_dog();
		*ip_add = (unsigned char)Disp_Buff[i];
		ip_add++;
	}
}

/***********************************************************************************************************************
* Function Name: ErrorDisplay
* Description  : This function is used to display error code.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void ErrorDisplay(void)
{
	unsigned char i;
	
	Disp_Buff[0] = 0xDA;
	Disp_Buff[1] = 0x18;
	Disp_Buff[2] = 0x18;

	if(BatteryWarningFlg)
	{
		Disp_Buff[2] |= 0x01;
	}

	for(i=3; i<=20; i++)
	{
		feed_dog();
		Disp_Buff[i] = 0x00;
	}
}




