/***********************************************************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only 
* intended for use with Renesas products. No other uses are authorized. This 
* software is owned by Renesas Electronics Corporation and is protected under 
* all applicable laws, including copyright laws.
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING 
* THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT 
* LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE 
* AND NON-INFRINGEMENT.  ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
* TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS 
* ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES SHALL BE LIABLE 
* FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR 
* ANY REASON RELATED TO THIS SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE 
* BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software 
* and to discontinue the availability of this software.  By using this software, 
* you agree to the additional terms and conditions found by accessing the 
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2011, 2013 Renesas Electronics Corporation. All rights reserved.
***********************************************************************************************************************/

/***********************************************************************************************************************
* File Name    : r_main.c
* Device(s)    : R7F0C004M2DFB
* Tool-Chain   : CA78K0R
* Description  : This file implements main function.
* Creation Date: 2013-12-11
***********************************************************************************************************************/

/***********************************************************************************************************************
Pragma directive
***********************************************************************************************************************/
/* Start user code for pragma. Do not edit comment generated here */
/* End user code. Do not edit comment generated here */
/*
#pragma sfr
#pragma DI
#pragma EI
#pragma NOP
#pragma HALT
#pragma STOP
*/


/***********************************************************************************************************************
Includes
***********************************************************************************************************************/
#include "r_macrodriver.h"
#include "r_user.h"



/***********************************************************************************************************************
Global variables and functions
***********************************************************************************************************************/
void R_MAIN_UserInit(void);
void hdwinit(void);
void R_PortInit(void);
void R_EdgeInterrupt(void);
void R_CGC_Create(void);
void R_CGC_Get_ResetSource(void);




/***********************************************************************************************************************
* Function Name: main
* Description  : This function implements main function.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void main(void)
{
	unsigned char i;
	for(i=0;i<=200;i++)
	{
		feed_dog();	
	}

	R_MAIN_UserInit();
	NOP();
	R_ParameterClear();
	NOP();

	while(1U)
	{
		feed_dog();	
		if(Sys_status == 0)			/* standby status */
		{
			Stop_Setting();
		}

		if(timer_60s_over)
		{
			Stop_Setting();
		}

		if(timer_10s_over)
		{
			BatteryVoltageDetect();
		}

		ModeOperation();
		NOP();
		NormalOperation();
		NOP();
	}
}


/***********************************************************************************************************************
* Function Name: R_MAIN_UserInit
* Description  : This function adds user code before implementing main function.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_MAIN_UserInit(void)
{
    DI();
    hdwinit();
    EI();
}


/***********************************************************************************************************************
* Function Name: R_Systeminit
* Description  : This function initializes every macro.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_Systeminit(void)
{
    PIOR = 0x00U;		//peripheral I/O redirection register
    R_CGC_Get_ResetSource();
    R_CGC_Create();
    CRC0CTL = 0x00U;	//Flash memory CRC control register
    IAWCTL = 0x00U;		//Invalid memory access detection control register
}


/***********************************************************************************************************************
* Function Name: hdwinit
* Description  : This function initializes hardware setting.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void hdwinit(void)
{
    DI();
    R_Systeminit();
    R_PortInit();
	R_EdgeInterrupt();
}


/***********************************************************************************************************************
* Function Name: R_CGC_Get_ResetSource
* Description  : This function process of Reset.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_CGC_Get_ResetSource(void)
{
    unsigned char reset_flag = RESF;
}


/***********************************************************************************************************************
* Function Name: R_CGC_Create
* Description  : This function initializes the clock generator.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_CGC_Create(void)
{
	OSMC = 0x90;		//Subsystem clock supply mode control register
				//Enable supplying subsystem clock to peripheral function, selection of operation clock for 12-bit interval timer and LCD controller/driver
	CMC = 0x40;		//Clock operation mode control register
    				//X1 oscillation mode, subsystem clock pins are input port mode, 1MHz <= fx <=10MHz
	CSC = 0x41;		//Clock operation status control register
    				//X1 oscilator operating, XT1 oscillator operating, high speed on chip oscillator stopped
	CKC = 0x00;		//System clock control register
    				//Main system clock is used to CPU/peripheral hardware clock
	OSTS = 0x07;		//Oscillation stabilization time select register
						//The longest time is selected
	HOCODIV = 0x02;

	PER0 = 0x00;
	PER1 = 0x00;
	PER2 = 0x00;

	DSCCTL = 0x00;
	MCKC = 0x00;
//	UCKSEL = 0x0000;
}


/***********************************************************************************************************************
* Function Name: R_PortInit
* Description  : This function initializes the port.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_PortInit(void)
{
	PM0 = 0x58;		//
	PM1 = 0x00;
	PM2 = 0x00;
	PM3 = 0x00;
	PM4 = 0x81;
	PM5 = 0x00;
	PM6 = 0xFC;
	PM7 = 0x00;
//	PM8 = 0x00;
	PM12 = 0xFF;
	PM14 = 0xF0;
	PM15 = 0x81;

	//All pins have not pull-on resistor
	PU0 = 0x00;
	PU1 = 0x00;
	PU2 = 0x00;
	PU3 = 0x00;
	PU4 = 0x00;
	PU5 = 0x00;
	PU7 = 0x00;
//	PU8 = 0x00;
	PU12 = 0x00;
	PU14 = 0x00;

	//The input mode of all pins are normal input mode
	PIM0 = 0x00;
	PIM1 = 0x00;
	PIM2 = 0x00;
	PIM3 = 0x00;
	PIM4 = 0x00;
	
	//The output mode of all pins are normal output mode
	POM0 = 0x00;
	POM1 = 0x00;
	POM2 = 0x00;
	POM3 = 0x00;
	POM4 = 0x00;

	PMC2 = 0xFC;			//P2.0 and P2.1 are digital I/O
	PMC4 = 0x00;			//P4.1 to P4.6 are digital I/O
	PMC14 = 0xF0;			//P14.0 to P14.3 are digital I/O

	ADPC = 0x02;			//ANI0/P150 is used to A/D converter
	PIOR = 0x00;			//Disable the peripheral I/O redirect function
	GAIDIS = 0x00;			//Input to input buffers permitted

	PFSEG0 = 0xF0;			//SEG04 to SEG07 are used as segment output
	PFSEG1 = 0xFF;			//SEG08 to SEG15 are used as segment output
	PFSEG2 = 0xFF;			//SEG16 to SEG23 are used as segment output
	PFSEG3 = 0x01;			//Only SEG24 is used as segment output
	PFSEG4 = 0x00;
	PFSEG5 = 0x00;
	PFSEG6 = 0x00;

//	ISCLCD = 0x00;			//Setting VL3/P125, CAPL/P126 and CAPH/P127 digital input ineffective

	P0 = 0x00;				//Disable P0.5/50Hz output
	P1 = 0x00;
	P2 = 0x00;
	P3 = 0x00;				//Disable LCD display
	P4 = 0x00;
	P5 = 0x00;				//Disable LCD display
	P6 = 0x00;
	P7 = 0x00;				//Disable LCD display
//	P8 = 0x00;
	P12 = 0x00;
	P13 = 0x00;				//Disable background light
	P14 = 0x01;				//Disable power supply
	P15 = 0x00;
	
}


/***********************************************************************************************************************
* Function Name: R_EdgeInterrupt
* Description  : This function initializes edge interrupt, used for POWER_ON and MODE setting.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_EdgeInterrupt(void)
{
	PIF2 = 0U;
	PMK2 = 1U;

	PPR02 = 0U;
	PPR12 = 0U;
	
	PIF5 = 0U;
	PMK5 = 1U;

	PPR05 = 0U;
	PPR15 = 0U;

	EGP0.2 = 0U;		/* intp2 is falling edge */
	EGN0.2 = 1U;

	EGP0.5 = 0U;		/* intp5 is falling edge */
	EGN0.5 = 1U;

	PIF2 = 0U;		/* enable intp2 MODE KEY */
	PMK2 = 0U;

	PIF5 = 0U;		/* enable intp5 POWER_ON KEY */
	PMK5 = 0U;
}



