/***********************************************************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only 
* intended for use with Renesas products. No other uses are authorized. This 
* software is owned by Renesas Electronics Corporation and is protected under 
* all applicable laws, including copyright laws.
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING 
* THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT 
* LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE 
* AND NON-INFRINGEMENT.  ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
* TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS 
* ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES SHALL BE LIABLE 
* FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR 
* ANY REASON RELATED TO THIS SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE 
* BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software 
* and to discontinue the availability of this software.  By using this software, 
* you agree to the additional terms and conditions found by accessing the 
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2013 Renesas Electronics Corporation. All rights reserved.
***********************************************************************************************************************/

/***********************************************************************************************************************
* File Name    : r_tau_user.c
* Device(s)    : R5F110PJAFB
* Tool-Chain   : CA78K0R
* Description  : This file implements device driver for TAU module.
* Creation Date: 2014/6/24
***********************************************************************************************************************/

/***********************************************************************************************************************
Pragma directive
***********************************************************************************************************************/
#pragma interrupt INTTM00 r_tau0_channel0_interrupt			/* measurement of high/low level width of input signal */
#pragma interrupt INTTM01 r_tau0_channel1_interrupt			/* 2 ms timer */


/* Start user code for pragma. Do not edit comment generated here */
/* End user code. Do not edit comment generated here */

/***********************************************************************************************************************
Includes
***********************************************************************************************************************/
#include "r_macrodriver.h"


/* Start user code for include. Do not edit comment generated here */
/* End user code. Do not edit comment generated here */

/***********************************************************************************************************************
Global variables and functions
***********************************************************************************************************************/
/* For TAU0_ch0 pulse measurement */
volatile unsigned long int g_tau0_ch0_width;

unsigned char Time_Count;
unsigned long int Width_Result;

unsigned char timer_20ms;
unsigned int timer_3s;
unsigned int timer_60s;
unsigned int timer_10s;

union bit_def timer_flag;
#define timer_3s_flg timer_flag.bi.b0
#define timer_3s_over timer_flag.bi.b1
#define timer_10s_flg timer_flag.bi.b2
#define timer_10s_over timer_flag.bi.b3
#define timer_60s_flg timer_flag.bi.b4
#define timer_60s_over timer_flag.bi.b5
#define WidthDetect_Over timer_flag.bi.b6


/*
boolean timer_3s_flg;
boolean timer_3s_over;
boolean timer_60s_flg;
boolean timer_60s_over;
boolean timer_10s_flg;
boolean timer_10s_over;
*/

void R_TAU0_Create(void);
void R_TAU0_Channel0_Start(void);
void R_TAU0_Channel0_Stop(void);
void R_TAU0_Channel0_Get_PulseWidth(unsigned long int * const width);
void R_TAU0_Channel1_Start(void);
void R_TAU0_Channel1_Stop(void);
void R_TAU0_Channel2_Start(void);
void R_TAU0_Channel2_Stop(void);


extern void SegDisplay(void);


extern unsigned char Disp_Buff[25];
extern unsigned char Sys_status;
//extern boolean BatteryWarningFlg;


/* Start user code for global. Do not edit comment generated here */
/* End user code. Do not edit comment generated here */

/***********************************************************************************************************************
* Function Name: R_TAU0_Create
* Description  : This function initializes the TAU0 module.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_TAU0_Create(void)
{
    TAU0EN = 1U;    	/* supplies input clock */
    TPS0 = 0x0030U;	/* CK01->fclk/2^3, 1.25MHz, CK00->fclk, 10MHz, CK02->fclk/2, 5MHz, CK03->fclk/2^8, 39.1KHz */
    
    TT0 = 0x0AFF;	/* Stop all channels */

    /* Mask channel 0 interrupt */
    TMMK00 = 1U;    /* disable INTTM00 interrupt */
    TMIF00 = 0U;    /* clear INTTM00 interrupt flag */
    /* Mask channel 1 interrupt */
    TMMK01 = 1U;    /* disable INTTM01 interrupt */
    TMIF01 = 0U;    /* clear INTTM01 interrupt flag */
    /* Mask channel 1 higher 8 bits interrupt */
    TMMK01H = 1U;    /* disable INTTM01H interrupt */
    TMIF01H = 0U;    /* clear INTTM01H interrupt flag */
    /* Mask channel 2 interrupt */
    TMMK02 = 1U;    /* disable INTTM02 interrupt */
    TMIF02 = 0U;    /* clear INTTM02 interrupt flag */
    /* Mask channel 3 interrupt */
    TMMK03 = 1U;    /* disable INTTM03 interrupt */
    TMIF03 = 0U;    /* clear INTTM03 interrupt flag */
    /* Mask channel 3 higher 8 bits interrupt */
    TMMK03H = 1U;    /* disable INTTM03H interrupt */
    TMIF03H = 0U;    /* clear INTTM03H interrupt flag */
    /* Mask channel 4 interrupt */
    TMMK04 = 1U;    /* disable INTTM04 interrupt */
    TMIF04 = 0U;    /* clear INTTM04 interrupt flag */
    /* Mask channel 5 interrupt */
    TMMK05 = 1U;    /* disable INTTM05 interrupt */
    TMIF05 = 0U;    /* clear INTTM05 interrupt flag */
    /* Mask channel 6 interrupt */
    TMMK06 = 1U;    /* disable INTTM06 interrupt */
    TMIF06 = 0U;    /* clear INTTM06 interrupt flag */
    /* Mask channel 7 interrupt */
    TMMK07 = 1U;    /* disable INTTM07 interrupt */
    TMIF07 = 0U;    /* clear INTTM07 interrupt flag */

    /* Set INTTM00 high priority */
    TMPR100 = 0U;
    TMPR000 = 0U;

    /* Set INTTM01 high priority */
    TMPR101 = 0U;
    TMPR001 = 0U;

    /* Channel 0 is used to measure input pulse low-/high-width */
    TMR00 = 0x828CU;	/* Operation clock CK01, independent channel function */
    			/* Both the edges of the TI00 pin input are used as start trigger and a capture trigger */
    			/* Both edges, start trigger: falling edge, capture trigger: rising edge */
    			/* Capture & one-count mode */
    TO0 &= ~0x0001U;	/* Timer output value is 1 */
    TOE0 &= ~0x0001U;	/* Timer output is enabled */
    NFEN1 |= 0x01U;	/* enable using noise filter of TI00 pin input signal */

    /* Channel 1 used as interval timer */
    TMR01 = 0x0000U;
    TDR01 = 0x3E7FU;
//    TDR01 = 0x4E1FU;	/* _4E1F_TAU_TDR01_VALUE */
//    TDR01 = 0xBB7FU;	/* _BB7F_TAU_TDR01_VALUE */
    TOM0 &= ~0x0002U;	/* _0002_TAU_CH1_OUTPUT_COMBIN */
    TOL0 &= ~0x0002U;	/* _0002_TAU_CH1_OUTPUT_LEVEL_L */
    TO0 &= ~0x0002U;	/* _0002_TAU_CH1_OUTPUT_VALUE_1 */
    TOE0 &= ~0x0002U;	/* _0002_TAU_CH1_OUTPUT_ENABLE */

    /* Channel 2 is used as master channel for PWM output function */
    TMR02 = 0x8801U;	/* Operation clock CK01, master channel function */
    			/* Only software trigger start is valid (other trigger sources are unselected */
    			/* Interval timer mode, timer interrupt is generated when counting is started */
    TDR02 = 0x4E1FU;	/* _EA5F_TAU_TDR02_VALUE */
    TOM0 &= ~0x0004U;	/* _0004_TAU_CH2_OUTPUT_COMBIN */
    TOL0 &= ~0x0004U;	/* _0004_TAU_CH2_OUTPUT_LEVEL_L */
    TO0 &= ~0x0004U;	/* _0004_TAU_CH2_OUTPUT_VALUE_1 */
    TOE0 &= ~0x0004U;	/* _0004_TAU_CH2_OUTPUT_ENABLE */

    /* Channel 6 is used as slave channel for PWM output function */
    TMR06 = 0x8409U;	/* Operation clock CK01, slave channel function */
    			/* Interrupt signal of the mater channel is used */
    			/* One-count mode, start trigger is valid during counting operation */
//    TDR06 = 0x07D0U;	/* _1770_TAU_TDR06_VALUE, 1:9 */
    TDR06 = 0x4650U;	/* _1770_TAU_TDR06_VALUE, 9:1 */
    TOM0 |= 0x0040U;	/* _0008_TAU_CH6_OUTPUT_COMBIN */
    TOL0 &= ~0x0040U;	/* _0008_TAU_CH6_OUTPUT_LEVEL_L */
    TO0 |= 0x0040U;	/* _0008_TAU_CH6_OUTPUT_VALUE_1 */
    TOE0 |= 0x0040U;	/* _0008_TAU_CH6_OUTPUT_ENABLE */

    /* Set TI00 pin and TO02 pin */
    PFSEG5 &= 0x00U;
    PM0 |= 0x08U;
    P0 &= 0x00U;
}



/***********************************************************************************************************************
* Function Name: R_TAU0_Channel0_Start
* Description  : This function starts TAU0 channel 0 counter.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_TAU0_Channel0_Start(void)
{
    TMIF00 = 0U;    /* clear INTTM00 interrupt flag */
    TMMK00 = 0U;    /* enable INTTM00 interrupt */
    TS0 |= 0x0001U;	/* _0001_TAU_CH0_START_TRG_ON */
}

/***********************************************************************************************************************
* Function Name: R_TAU0_Channel0_Stop
* Description  : This function stops TAU0 channel 0 counter.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_TAU0_Channel0_Stop(void)
{
    TT0 |= 0x0001U;	/* _0001_TAU_CH0_STOP_TRG_ON */

    /* Mask channel 0 interrupt */
    TMMK00 = 1U;    /* disable INTTM00 interrupt */
    TMIF00 = 0U;    /* clear INTTM00 interrupt flag */
}

/***********************************************************************************************************************
* Function Name: R_TAU0_Channel0_Get_PulseWidth
* Description  : This function measures TAU0 channel 0 input pulse width.
* Arguments    : width -
*                    the address where to write the input pulse width
* Return Value : None
***********************************************************************************************************************/
void R_TAU0_Channel0_Get_PulseWidth(unsigned long int * const width)
{
    /* For channel 0 pulse measurement */
    *width = g_tau0_ch0_width;
}



/***********************************************************************************************************************
* Function Name: R_TAU0_Channel1_Start
* Description  : This function starts TAU0 channel 1 counter.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_TAU0_Channel1_Start(void)
{
    TMIF01 = 0U;    /* clear INTTM01 interrupt flag */
    TMMK01 = 0U;    /* enable INTTM01 interrupt */
    TS0 |= 0x0002U;	/* _0002_TAU_CH1_START_TRG_ON */
}

/***********************************************************************************************************************
* Function Name: R_TAU0_Channel1_Stop
* Description  : This function stops TAU0 channel 1 counter.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_TAU0_Channel1_Stop(void)
{
    TT0 |= 0x0002U;	/* _0002_TAU_CH1_STOP_TRG_ON */
    /* Mask channel 1 interrupt */
    TMMK01 = 1U;    /* disable INTTM01 interrupt */
    TMIF01 = 0U;    /* clear INTTM01 interrupt flag */
}


/***********************************************************************************************************************
* Function Name: R_TAU0_Channel2_Start
* Description  : This function starts TAU0 channel 2 counter.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_TAU0_Channel2_Start(void)
{
    TOE0 |= 0x0040U;	/* _0008_TAU_CH3_OUTPUT_ENABLE */
    TS0 |= 0x0044U;		/* _0004_TAU_CH2_START_TRG_ON | _0008_TAU_CH3_START_TRG_ON */
}

/***********************************************************************************************************************
* Function Name: R_TAU0_Channel2_Stop
* Description  : This function stops TAU0 channel 2 counter.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_TAU0_Channel2_Stop(void)
{
    TT0 |= 0x0044U;		/*_0004_TAU_CH2_STOP_TRG_ON | _0008_TAU_CH3_STOP_TRG_ON; */
    TOE0 &= ~0x0040U;	/* _0008_TAU_CH3_OUTPUT_ENABLE; */
}








/***********************************************************************************************************************
* Function Name: r_tau0_channel0_interrupt
* Description  : This function INTTM00 interrupt service routine, measurement of high/low level width of input signal.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
__interrupt static void r_tau0_channel0_interrupt(void)
{
    if (1U == (TSR00 & 0x0001U))    /* overflow occurs */
    {            
        g_tau0_ch0_width = (unsigned long int)(TDR00 + 1U) + 0x10000U;
    }
    else
    {
        g_tau0_ch0_width = (unsigned long int)(TDR00 + 1U);
    }

	Time_Count++;
	if(Time_Count == 1)
	{
		g_tau0_ch0_width = 0;
	}
	else
	{
		Width_Result += g_tau0_ch0_width;
		g_tau0_ch0_width = 0;
		if(Time_Count>=3)
		{
			Time_Count = 1;	
			Width_Result = Width_Result/2;
			WidthDetect_Over = 1;
		}
	}

    /* Start user code. Do not edit comment generated here */
    /* End user code. Do not edit comment generated here */
}




/***********************************************************************************************************************
* Function Name: r_tau0_channel1_interrupt
* Description  : This function INTTM01 interrupt service routine, 2 ms timer.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
__interrupt static void r_tau0_channel1_interrupt(void)
{
	unsigned char RunStage;

	if(timer_3s_flg)		//power_on, all LCD segments display 3 s
	{
		timer_3s++;
		if(timer_3s >= 1500)
		{
			timer_3s_over = 1;
			timer_3s_flg = 0;
			timer_3s = 0;
		}
	}

	if(timer_10s_flg)
	{
		timer_10s++;
		if(timer_10s >= 5000)
		{
			timer_10s_over =1;
			timer_10s_flg = 0;
			timer_10s = 0;
		}
	}

	if(timer_60s_flg)
	{
		timer_60s++;
		if(timer_60s >= 30000)
		{
			timer_60s_over = 1;
			timer_60s_flg = 0;
			timer_60s = 0;
		}
	}

	RunStage = Sys_status;
	RunStage &= 0xF0;
	if(RunStage == 0x20)
	{
		timer_20ms++;
		if(timer_20ms >= 10)
		{
			timer_20ms = 0;
			SegDisplay();
		}
	}

//	BackLight_Con = ~BackLight_Con;


    /* Start user code. Do not edit comment generated here */
    /* End user code. Do not edit comment generated here */
}





/* Start user code for adding. Do not edit comment generated here */
/* End user code. Do not edit comment generated here */
