/***********************************************************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only 
* intended for use with Renesas products. No other uses are authorized. This 
* software is owned by Renesas Electronics Corporation and is protected under 
* all applicable laws, including copyright laws.
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING 
* THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT 
* LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE 
* AND NON-INFRINGEMENT.  ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
* TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS 
* ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES SHALL BE LIABLE 
* FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR 
* ANY REASON RELATED TO THIS SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE 
* BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software 
* and to discontinue the availability of this software.  By using this software, 
* you agree to the additional terms and conditions found by accessing the 
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2011, 2013 Renesas Electronics Corporation. All rights reserved.
***********************************************************************************************************************/

/***********************************************************************************************************************
* File Name    : r_main.c
* Device(s)    : R7F0C004M2DFB
* Tool-Chain   : CA78K0R
* Description  : This file implements main function.
* Creation Date: 2013-12-11
***********************************************************************************************************************/

/***********************************************************************************************************************
Pragma directive
***********************************************************************************************************************/
/* Start user code for pragma. Do not edit comment generated here */
/* End user code. Do not edit comment generated here */


/***********************************************************************************************************************
Includes
***********************************************************************************************************************/
#include "r_macrodriver.h"
#include "r_user.h"
#include "stdlib.h"




/***********************************************************************************************************************
Global variables and functions
***********************************************************************************************************************/
unsigned int BloodPressureValue;
unsigned int Old_BloodValue;
unsigned long int ZeroPoint_Data;
unsigned long int FullPoint_Data;
unsigned long int UnitBloodPressure;
//unsigned int mmHg_Value;		//bcd code
unsigned char NormalDispMode;



void Stop_Setting(void);
void NormalOperation(void);
void ModeOperation(void);
void R_ParameterClear(void);
void Power_on_display(void);
void BatteryVoltageDetect(void);
void PressureCalculation(void);
void SaveZeroData(void);
void SaveFullData(void);
void Read_Zero_Full_Data(void);
void Cal_UnitBloodPressure(void);


void M_StartupModule(void);
void M_CloseModule(void);
void M_ParameterInit(void);
void StartupADC(void);


/***********************************************************************************************************************
* Function Name: Stop_Setting
* Description  : This function sets standby mode.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void Stop_Setting(void)
{
	feed_dog();

	M_CloseModule();

	/* stop all peripheral hardware clock */
	PER0 = 0x00;
	PER1 = 0x00;
	PER2 = 0x00;

	PIF5 = 0U;	/* enable intp5 MODE KEY */
	PMK5 = 0U;	
	PIF2 = 0U;	/* enable intp2 power on KEY */
	PMK2 = 0U;

	NOP();
	NOP();
	NOP();
	STOP();
	NOP();
	NOP();
	NOP();	
}

/***********************************************************************************************************************
* Function Name: NormalOperation
* Description  : This function represent system normal operation.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void NormalOperation(void)
{
	unsigned char i;

	if(Sys_status == 0x10)			/* normal run status */
	{
		Sys_status = 0x11;
		R_TAU0_Create();
		R_LCD_Create();
		R_ADC_Setting();
		Power_on_display();
		Read_Zero_Full_Data();
		Cal_UnitBloodPressure();
	}
	else if(Sys_status == 0x11)
	{
		if(timer_3s_over)
		{
			BackLight_Con = 0;

			/* stop 3s timer */
			timer_3s_over = 0;
			timer_3s_flg = 0;
			timer_3s = 0;
			
			Sys_status = 0x12;

			WidthDetect_Over = 0;
			Width_Result = 0;
			Time_Count = 0;
			BloodPressureValue = 0;

			/* start peripheral hardware power supply */
			Power4v_CE = 1;
			Power4v_Con = 0;
			BackLight_Con = 0;

			R_TAU0_Channel0_Start();		/* begin pulse width measurement */
			R_TAU0_Channel2_Start();		/* begin 1:9 / 50Hz PWM output */

			R_LCD_ClearZero();

			/*--------for lcd testing----------*/
/*
			BloodPressureValue = 0;
			for(i=0; i<300; i++)
			{
				feed_dog();
				BloodPressureValue++;
				NormalDisplay();
				NOP();
			}
*/
			NormalDisplay();

			/* startup battery voltage detection */
			StartupADC();
		}
	}
	else if(Sys_status == 0x12)
	{
		if(WidthDetect_Over)
		{
			WidthDetect_Over = 0;
			PressureCalculation();
			NormalDisplay();

			if(Old_BloodValue != BloodPressureValue)
			{
				timer_60s_over = 0;
				timer_60s_flg = 1;
				timer_60s = 0;

				Old_BloodValue = BloodPressureValue;
			}
		}
	}	
}


/***********************************************************************************************************************
* Function Name: ModeOperation
* Description  : This function represent system mode operation.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void ModeOperation(void)
{
	unsigned char i;

	if(Sys_status == 0x20)				//Parameters setting mode
	{
		Sys_status = 0x21;
		M_StartupModule();
		M_ParameterInit();

		/* start peripheral hardware power supply */
		Power4v_CE = 1;
		Power4v_Con = 0;
		BackLight_Con = 0;

		ModeDisplay();
	}	
	else if(Sys_status == 0x21)		/* debug run status */
	{
		if(ModeCount == 0x02)
		{
			feed_dog();
			SaveZeroData();
			Disp_Buff[2] = 0xBA;
/*
			if(BatteryWarningFlg)
			{
				Disp_Buff[2] |= 0x01;
			}
*/
			StartupADC();
			Sys_status = 0x22;
			WidthDetect_Over = 0;
		}
	}
	else if(Sys_status == 0x22)
	{
		if(ModeCount == 0x03)
		{
			feed_dog();
			if(Width_Result <= (ZeroPoint_Data + 300))
			{
				ModeCount--;
				PIF5 = 0U;
				PMK5 = 0U;
				ErrorDisplay();
				return;
			}

			SaveFullData();
			M_CloseModule();
			Sys_status = 0x10;
			for(i=0; i<100; i++)
			{
				feed_dog();
			}
		}
	}	
}





/***********************************************************************************************************************
* Function Name: R_ParameterClear
* Description  : This function is used to clear the parameters.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_ParameterClear(void)
{
	g_tau0_ch0_width = 0;
	Sys_status = 0;
	ModeCount = 0;
	ZeroPoint_Data = 0;
	FullPoint_Data = 0;
	NormalDispMode = 0;
//	mmHg_Value = 0;
//	Power_status.byte = 0;
	timer_flag.byte = 0;
	timer_3s = 0;
	timer_10s = 0;
	timer_60s = 0;
}


/***********************************************************************************************************************
* Function Name: Power_on_display
* Description  : This function is used to display lcd all screen 3s.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void Power_on_display(void)
{
	/* begin 3s,15s and 60s timer */
	timer_3s = 0;
	timer_10s = 0;
	timer_60s = 0;
	timer_3s_over = 0;
	timer_10s_over = 0;
	timer_60s_over = 0;
	timer_3s_flg = 1;
	timer_10s_flg = 1;
	timer_60s_flg = 1;

	R_TAU0_Channel1_Start();

	/* lcd all screen display 3s */
	R_LCD_Allshine();
	R_LCD_Voltage_On();
	R_LCD_Start();
	BackLight_Con = 1;
}


/***********************************************************************************************************************
* Function Name: BatteryVoltageDetect
* Description  : This function is used to detect battery voltage.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void BatteryVoltageDetect(void)
{
	/* restart 15s timer */
	timer_10s_over = 0;
	timer_10s = 0;
	timer_10s_flg = 1;

	/* start AD converter */
	AD_ResultCount =0;
	AD_CurrentValue = 0;
//	BatteryWarningFlg = 0;

	ADCEN = 1U;
	R_ADC_Set_OperationOn();
	R_ADC_Start();
}

/***********************************************************************************************************************
* Function Name: PressureCalculation
* Description  : This function is used to calculat the pressure value.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void PressureCalculation(void)
{
	unsigned long int D_value;
	ldiv_t lx;

/*
	D_value = FullPoint_Data - ZeroPoint_Data;
	lx = ldiv(D_value, 300);
	if(lx.rem >= 150)
	{
		lx.quot++;
	}

	UnitBloodPressure = lx.quot;
*/

	if(Width_Result <= ZeroPoint_Data)
	{
		BloodPressureValue = 0x000;			/* hex code */
//		mmHg_Value = 0;
	}
	else
	{
		D_value = Width_Result - ZeroPoint_Data;
		lx = ldiv(D_value,UnitBloodPressure);
		if(lx.rem >= UnitBloodPressure/2)
		{
			lx.quot++;
		}

		BloodPressureValue = (unsigned int) lx.quot;

		if(BloodPressureValue >= 18)
		{
			BackLight_Con = 1;
		}
		else
		{
			BackLight_Con = 0;
		}
//		mmHg_Value = wtobcd(BloodPressureValue);
	}
}


/***********************************************************************************************************************
* Function Name: SaveZeroData
* Description  : This function is used to save zero point data to data flash.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void SaveZeroData(void)
{
	unsigned long int SavingDataBuff;
	unsigned long int *ip_add;
	unsigned char ret;

	SavingDataBuff = Width_Result;
	ZeroPoint_Data = Width_Result;
	ip_add = &SavingDataBuff;

	g_write_address = 0x0010;
	g_write_value = *((unsigned char*)ip_add);
	ret = R_FDL_ExecuteWrite();
	if(ret == PFDL_NG)
	{
		WDTE=0xff;
		return;
	}
	NOP();
	NOP();
	NOP();
	g_write_address = 0x0011;
	g_write_value = *(((unsigned char*)ip_add)+1);
	ret = R_FDL_ExecuteWrite();
	if(ret == PFDL_NG)
	{
		WDTE=0xff;
		return;
	}

	g_write_address = 0x0012;
	g_write_value = *(((unsigned char*)ip_add)+2);
	ret = R_FDL_ExecuteWrite();
	if(ret == PFDL_NG)
	{
		WDTE=0xff;
		return;
	}

	g_write_address = 0x0013;
	g_write_value = *(((unsigned char*)ip_add)+3);
	ret = R_FDL_ExecuteWrite();
	if(ret == PFDL_NG)
	{
		WDTE=0xff;
		return;
	}
}


/***********************************************************************************************************************
* Function Name: SaveFullData
* Description  : This function is used to save full point data to data flash.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void SaveFullData(void)
{
	unsigned long int SavingDataBuff;
	unsigned long int *ip_add;
	unsigned char ret;

	SavingDataBuff = Width_Result;
	FullPoint_Data = Width_Result;
	ip_add = &SavingDataBuff;

	g_write_address = 0x0020;
	g_write_value = *((unsigned char*)ip_add);
	ret = R_FDL_ExecuteWrite();
	if(ret == PFDL_NG)
	{
		WDTE=0xff;
		return;
	}
	NOP();
	NOP();
	NOP();
	g_write_address = 0x0021;
	g_write_value = *(((unsigned char*)ip_add)+1);
	ret = R_FDL_ExecuteWrite();
	if(ret == PFDL_NG)
	{
		WDTE=0xff;
		return;
	}

	g_write_address = 0x0022;
	g_write_value = *(((unsigned char*)ip_add)+2);
	ret = R_FDL_ExecuteWrite();
	if(ret == PFDL_NG)
	{
		WDTE=0xff;
		return;
	}

	g_write_address = 0x0023;
	g_write_value = *(((unsigned char*)ip_add)+3);
	ret = R_FDL_ExecuteWrite();
	if(ret == PFDL_NG)
	{
		WDTE=0xff;
		return;
	}
	
}

/***********************************************************************************************************************
* Function Name: Read_Zero_Full_Data
* Description  : This function is used to read zero point and full point data from data flash.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void Read_Zero_Full_Data(void)
{
	unsigned char tempData[8];
	unsigned long int *ip_add;
	signed int *id_add;
	NOP();
//	*((unsigned char *)(0x0090))=0x01;
	DFLCTL = 0x01U;
	NOP();
	tempData[0]=*((unsigned char *)(0x1010));
	NOP();
	tempData[1]=*((unsigned char *)(0x1011));
	NOP();
	tempData[2]=*((unsigned char *)(0x1012));
	NOP();
	tempData[3]=*((unsigned char *)(0x1013));
	NOP();
	tempData[4]=*((unsigned char *)(0x1020));
	NOP();
	tempData[5]=*((unsigned char *)(0x1021));
	NOP();
	tempData[6]=*((unsigned char *)(0x1022));
	NOP();
	tempData[7]=*((unsigned char *)(0x1023));
	NOP();
//	*((unsigned char *)(0x0090))=0x00;
	DFLCTL = 0x00U;
	NOP();

	ip_add=&ZeroPoint_Data;
	*((unsigned char *)(ip_add)) = tempData[0];
	*(((unsigned char *)(ip_add))+1) = tempData[1];
	*(((unsigned char *)(ip_add))+2) = tempData[2];
	*(((unsigned char *)(ip_add))+3) = tempData[3];

	ip_add=&FullPoint_Data;
	*((unsigned char *)(ip_add)) = tempData[4];
	*(((unsigned char *)(ip_add))+1) = tempData[5];
	*(((unsigned char *)(ip_add))+2) = tempData[6];
	*(((unsigned char *)(ip_add))+3) = tempData[7];
}



/***********************************************************************************************************************
* Function Name: Read_Zero_Full_Data
* Description  : This function is used to read zero point and full point data from data flash.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void Cal_UnitBloodPressure(void)
{
	unsigned long int D_value;
	ldiv_t lx;

	D_value = FullPoint_Data - ZeroPoint_Data;
	lx = ldiv(D_value, 300);
	if(lx.rem >= 150)
	{
		lx.quot++;
	}

	UnitBloodPressure = lx.quot;	
}



/***********************************************************************************************************************
* Function Name: M_StartupModule
* Description  : This function is used to start up all peripheral hardware module.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void M_StartupModule(void)
{
	R_TAU0_Create();
	R_LCD_Create();
	R_ADC_Setting();

	R_TAU0_Channel0_Start();	/* begin pulse width measurement */
	R_TAU0_Channel1_Start();	/* begin interval timer */
	R_TAU0_Channel2_Start();	/* begin 1:9 / 50Hz PWM output */
		
	R_LCD_ClearZero();
	R_LCD_Voltage_On();
	R_LCD_Start();	
}

/***********************************************************************************************************************
* Function Name: M_CloseModule
* Description  : This function is used to close all peripheral hardware module.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void M_CloseModule(void)
{
	/* stop peripheral hardware power supply */
	Power4v_CE = 0;
	Power4v_Con = 1;
	BackLight_Con = 0;
	
	/* stop timer array unit */
	R_TAU0_Channel0_Stop();
	R_TAU0_Channel1_Stop();
	R_TAU0_Channel2_Stop();

	/* stop lcd module */
	R_LCD_ClearZero();
	R_LCD_Voltage_Off();
	R_LCD_Stop();

	/* stop ad module */
	R_ADC_Set_OperationOff();
	R_ADC_Stop();

	/* stop intervel timer */
	R_IT_Stop();
	
	R_ParameterClear();
}



/***********************************************************************************************************************
* Function Name: M_ParameterInit
* Description  : This function is used to start up all peripheral hardware module.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void M_ParameterInit(void)
{
	timer_20ms = 0;
	timer_3s = 0;
	timer_10s = 0;
	timer_60s = 0;
	timer_3s_over = 0;
	timer_10s_over = 1;
	timer_60s_over = 0;
	timer_3s_flg = 0;
	timer_10s_flg = 0;
	timer_60s_flg = 1;	

	g_tau0_ch0_width = 0;
	ZeroPoint_Data = 0;
	FullPoint_Data = 0;
//	mmHg_Value = 0;
}

/***********************************************************************************************************************
* Function Name: StartupADC
* Description  : This function is used to start up ADC.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void StartupADC(void)
{
	timer_10s_over = 1U;
	timer_10s_flg = 1U;
	timer_10s = 0U;
	ADCEN = 1U;
	R_ADC_Set_OperationOn();
	R_ADC_Start();
}

