/*******************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only
* intended for use with Renesas products. No other uses are authorized. This
* software is owned by Renesas Electronics Corporation and is protected under
* all applicable laws, including copyright laws.
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING
* THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT
* LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE
* AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
* TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS
* ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES SHALL BE LIABLE
* FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR
* ANY REASON RELATED TO THIS SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE
* BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software
* and to discontinue the availability of this software. By using this software,
* you agree to the additional terms and conditions found by accessing the
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2011-2013 Renesas Electronics Corporation. All rights reserved.
*******************************************************************************/

/***********************************************************************************************************************
* File Name    : r_user.h
* Device(s)    : R7F0C004M2DFB
* Tool-Chain   : CA78K0R
* Description  : This file implements device driver for ADC module.
* Creation Date: 2013-12-11
***********************************************************************************************************************/


#ifndef __USER_H_INCLUDED
#define __USER_H_INCLUDED


/***********************************************************************************************************************
User definitions
***********************************************************************************************************************/

/* Start user code for function. Do not edit comment generated here */

//#define FLASH_START_ADDRESS    (0xF1000)                               /* Start address of data flash                */
//#define TARGET_BLOCK           (0)                                     /* Block number of target(0 ~ 3)              */
//#define BLOCK_SIZE             (0x400)                                 /* Block size                                 */
//#define WRITE_SIZE             (1)                                     /* Size of data to be written at once         */
//#define MAX_VALUE              (0xFF)                                  /* Maximum value of writing                   */
//#define MAX_ADDRESS            ((TARGET_BLOCK + 1) * BLOCK_SIZE - 1)   /* Maximum address of writing                 */
//#define PFDL_NG                (1)                                     /* Failure to Data Flash                      */
//#define FDL_FRQ                (24)                                    /* Setting frequency (MHz)                    */
//#define FDL_VOL                (0x00)                                  /* Voltage mode                               */
//#define LCD_SIZE               (8)                                     /* Maximum number can be displayed on the LCD */

/***********************************************************************************************************************
Exported global functions (to be accessed by other files)
***********************************************************************************************************************/
/*
void    R_MAIN_INTCStart(void);
void    R_MAIN_INTCStop(void);
void    R_MAIN_ClearSwitchFlag(void);
unsigned char R_MAIN_GetSwitchStatus(void);
void    R_MAIN_IncrementValue(void);
unsigned char R_MAIN_DetectLongPush(void);
unsigned char R_MAIN_SwitchProcess(unsigned char sw_status);
void    R_MAIN_UpdateStringUpper(signed char upper_string[LCD_SIZE + 1]);
void    R_MAIN_UpdateStringDowner(signed char downer_string[LCD_SIZE + 1]);


extern void R_FDL_Init(void);
extern unsigned char R_FDL_BlankCheck(void);
extern unsigned char R_FDL_Erase(void);
extern unsigned char R_FDL_Verify(void);
extern void R_FDL_Read(void);
extern unsigned char R_FDL_Write(void);
extern void R_FDL_ChangeAddress(void);
extern unsigned char R_FDL_ExecuteWrite(void);
extern unsigned char R_FDL_ClearDataFlash(void);
*/


//#if    TARGET_BLOCK > 3
//#error target_block error!!
//#endif



/***********************************************************************************************************************
Global variables and functions
***********************************************************************************************************************/

extern void R_IT_Stop(void);
extern void R_IT_Start(void);

extern void R_ADC_Setting(void);
extern void R_ADC_Start(void);
extern void R_ADC_Stop(void);
extern void R_ADC_Set_OperationOn(void);
extern void R_ADC_Set_OperationOff(void);

extern void R_LCD_Create(void);
extern void R_LCD_Start(void);
extern void R_LCD_Stop(void);
extern void R_LCD_Voltage_On(void);
extern void R_LCD_Voltage_Off(void);
extern void R_LCD_ClearZero(void);
extern void R_LCD_Allshine(void);
extern void SegDisplay(void);
extern void ErrorDisplay(void);

extern void R_TAU0_Create(void);
extern void R_TAU0_Channel0_Start(void);
extern void R_TAU0_Channel0_Stop(void);
extern void R_TAU0_Channel0_Get_PulseWidth(unsigned long int * const width);
extern void R_TAU0_Channel1_Start(void);
extern void R_TAU0_Channel1_Stop(void);
extern void R_TAU0_Channel2_Start(void);
extern void R_TAU0_Channel2_Stop(void);


extern void Stop_Setting(void);
extern void NormalOperation(void);
extern void ModeOperation(void);
extern void R_ParameterClear(void);
extern void Power_on_display(void);
extern void BatteryVoltageDetect(void);
extern void PressureCalculation(void);

extern void ModeDisplay(void);
extern void NormalDisplay(void);

extern void SaveZeroData(void);
extern void SaveFullData(void);
extern void Read_Zero_Full_Data(void);

extern void R_FDL_Init(void);
extern unsigned char R_FDL_BlankCheck(void);
extern unsigned char R_FDL_Erase(void);
extern unsigned char R_FDL_Verify(void);
extern void R_FDL_Read(void);
extern unsigned char R_FDL_Write(void);
extern void R_FDL_ChangeAddress(void);
extern unsigned char R_FDL_ExecuteWrite(void);
extern unsigned char R_FDL_ClearDataFlash(void);


extern unsigned char Sys_status;
extern unsigned char ModeCount;
extern volatile unsigned long int g_tau0_ch0_width;


extern unsigned char g_write_value;
extern unsigned int g_write_address;
extern unsigned char g_read_value;

extern unsigned char Disp_Buff[25];

extern unsigned char AD_ResultCount;
extern unsigned int AD_CurrentValue;
extern boolean BatteryWarningFlg;

extern unsigned char Time_Count;
extern unsigned long int Width_Result;
extern unsigned int BloodPressureValue;
extern unsigned int Old_BloodValue;
extern unsigned long int ZeroPoint_Data;
extern unsigned long int FullPoint_Data;
//extern unsigned int mmHg_Value;		//bcd code
extern unsigned char NormalDispMode;

extern unsigned char timer_20ms;
extern unsigned int timer_3s;
extern unsigned int timer_60s;
extern unsigned int timer_10s;

extern union bit_def timer_flag;

#define timer_3s_flg timer_flag.bi.b0
#define timer_3s_over timer_flag.bi.b1
#define timer_10s_flg timer_flag.bi.b2
#define timer_10s_over timer_flag.bi.b3
#define timer_60s_flg timer_flag.bi.b4
#define timer_60s_over timer_flag.bi.b5
#define WidthDetect_Over timer_flag.bi.b6


/*
extern boolean timer_3s_flg;
extern boolean timer_3s_over;
extern boolean timer_60s_flg;
extern boolean timer_60s_over;
extern boolean timer_10s_flg;
extern boolean timer_10s_over;
*/

/*
extern union bit_def Power_status;
#define Power_on_flg Power_status.bi.b0
#define Power_off_flg Power_status.bi.b1
*/

/*
extern boolean Power_on_flg;
extern boolean Power_off_flg;
*/
#endif
